Class: Octave::CellMatrix
Overview
The CellMatrix class is used for storing values that are sent to or received from Octave cell matrices. Usage:
require 'octave'
cell_matrix = Octave::CellMatrix.new(20, 400)
20.times { |m| 400.times { |n| cell_matrix[m, n] = rand.to_s } }
Instance Attribute Summary
Attributes inherited from Matrix
Method Summary
Methods inherited from Matrix
#==, #[], #[]=, #initialize, #to_a
Constructor Details
This class inherits a constructor from Octave::Matrix